@@ -10,7 +10,7 @@ def t01(data, length, pos):
 def t02(data, length, pos):
     if length > 16:
         raise Exception
-    return auto_unpack(str(length) + 'I', data, pos)
+    return auto_unpack('>' + str(length) + 'B', data, pos)
 
 
 def t04(data, length, pos):
@@ -60,15 +60,17 @@ def t30(data, length, pos):
         except:
             new_seq = None
             error = True
-
         if not new_seq:
             break
-
         seq.append(new_seq)
 
     return seq, new_pos
 
 
+def t0A(data, length, pos):
+    return t02(data, length, pos)
+
+
 decoder = {
     b'\x01': t01,
     b'\x02': t02,
@@ -76,16 +78,19 @@ decoder = {
     b'\x05': t05,
     b'\x06': t06,
     b'\x30': t30,
-
+    b'\x0A': t0A
 }
 
 
 def auto_unpack(fmt, data, pos=0):
     """自动计算unpack的大小并返回结果"""
-    len = struct.calcsize(fmt)
-    new_pos = pos + len
+    length = struct.calcsize(fmt)
+    new_pos = pos + length
     result = struct.unpack(fmt, data[pos:new_pos])
-    return *result, new_pos
+    if isinstance(result[0], bytes):
+        return bytes.join(b'', result), new_pos
+    else:
+        return *result, new_pos
 
 
 def _decode_length(data, pos):
@@ -108,4 +113,4 @@ def decode(data, pos=0):
     if etype in decoder:
         return decoder[etype](data, length, new_pos)
     else:
-        raise ValueError('no decoder type for type: {}'.format(etype))
+        return None, new_pos
